summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneycategory.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneycategory.h')
-rw-r--r--kmymoney2/widgets/kmymoneycategory.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmymoney2/widgets/kmymoneycategory.h b/kmymoney2/widgets/kmymoneycategory.h
index fa4998e..fa2975c 100644
--- a/kmymoney2/widgets/kmymoneycategory.h
+++ b/kmymoney2/widgets/kmymoneycategory.h
@@ -48,7 +48,7 @@ class kMyMoneyAccountSelector;
* If any match is found a list selection box is opened and the user can use
* the up/down, page-up/page-down keys or the mouse to navigate in the list. If
* an account is selected, the selection box is closed. Other key-strokes are
* directed to the tqparent object to manipulate the text. The visible contents of
* the selection box is updated with every key-stroke.
*
* This object is a replacement of the kMyMoneyCategory object and should be used
@@ -68,8 +68,8 @@ public:
* will construct a surrounding TQFrame and reparent itself to be a child of this
* TQFrame. It also adds a KPushButton with the "Split" icon to the right of the
* input field. In this case it is important not to use the pointer to this widget
- * but it's tqparent when placing the object in a TQLayout, TQTable or some such. The
- * tqparent widget (the TQFrame in this case) can be extracted with the parentWidget()
+ * but it's parent when placing the object in a TQLayout, TQTable or some such. The
+ * parent widget (the TQFrame in this case) can be extracted with the parentWidget()
* method.
*
* Reparenting is handled by the object transparently for both cases.
@@ -92,7 +92,7 @@ public:
* table->setCellWidget(category->parentWidget());
* @endcode
*/
- KMyMoneyCategory(TQWidget* tqparent = 0, const char* name = 0, bool splitButton = false);
+ KMyMoneyCategory(TQWidget* parent = 0, const char* name = 0, bool splitButton = false);
virtual ~KMyMoneyCategory();
@@ -112,7 +112,7 @@ public:
/**
* Reimplemented for internal reasons. No API change
*/
- virtual void reparent( TQWidget *tqparent, WFlags, const TQPoint &, bool showIt = FALSE );
+ virtual void reparent( TQWidget *parent, WFlags, const TQPoint &, bool showIt = FALSE );
/**
* Reimplemented for internal reasons. No API change.
@@ -180,7 +180,7 @@ class KMyMoneySecurity : public KMyMoneyCategory
Q_OBJECT
TQ_OBJECT
public:
- KMyMoneySecurity(TQWidget* tqparent = 0, const char* name = 0);
+ KMyMoneySecurity(TQWidget* parent = 0, const char* name = 0);
virtual ~KMyMoneySecurity();
/**
@@ -48,7 +48,7 @@ class kMyMoneyAccountSelector;
* the up/down, page-up/page-down keys or the mouse to navigate in the list. If
* an account is selected, the selection box is closed. Other key-strokes are
- * directed to the tqparent object to manipulate the text. The visible contents of
+ * directed to the parent object to manipulate the text. The visible contents of
* the selection box is updated with every key-stroke.
*